# Generated by Django 4.2.5 on 2023-10-07 14:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('paper_uploads', '0011_auto_20230506_0349'),
    ]

    operations = [
        migrations.AddField(
            model_name='fileitem',
            name='mimetype',
            field=models.CharField(default='', editable=False, max_length=128, verbose_name='MIME Type'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='imageitem',
            name='mimetype',
            field=models.CharField(default='', editable=False, max_length=128, verbose_name='MIME Type'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='svgitem',
            name='mimetype',
            field=models.CharField(default='', editable=False, max_length=128, verbose_name='MIME Type'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='uploadedfile',
            name='mimetype',
            field=models.CharField(default='', editable=False, max_length=128, verbose_name='MIME Type'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='uploadedimage',
            name='mimetype',
            field=models.CharField(default='', editable=False, max_length=128, verbose_name='MIME Type'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='uploadedsvgfile',
            name='mimetype',
            field=models.CharField(default='', editable=False, max_length=128, verbose_name='MIME Type'),
            preserve_default=False,
        ),
    ]
